pub struct ExportResolver<'a> {
modules: &'a BTreeMap<String, Module>,
}Expand description
Resolver for determining which items are exported from modules
Fields
modules: &'a BTreeMap<String, Module>Implementations
Sourceimpl<'a> ExportResolver<'a>
impl<'a> ExportResolver<'a>
pub fn new(modules: &'a BTreeMap<String, Module>) -> Self
Sourcepub fn resolve_exports(&self, module: &Module) -> BTreeSet<String>
pub fn resolve_exports(&self, module: &Module) -> BTreeSet<String>
Resolve which items are exported from a module Rules:
- If all exists (re-exports or verbatim): use it
- Otherwise: all non-underscore items
- Add re-exported items
- Add verbatim entries
- Remove excluded items
Sourcepub fn build_export_map(&self) -> BTreeMap<String, String>
pub fn build_export_map(&self) -> BTreeMap<String, String>
Build global map: item_fqn → module_where_exported For re-exports: map to re-exporting module